@@ -1,6 +1,7 @@
 #
 # Geo Accessor for DataFrames
 #
+import warnings
 import pandas as pd
 from ._array import GeosArray
 from ._delegated_dataframe import unary_dataframe_expanded
@@ -48,9 +49,15 @@ class GeosDataFrameAccessor:
             obj[geometry] = GeosArray(obj[geometry].array.data)
         elif (obj.dtypes != 'geos').all():
             raise AttributeError('Must have at least one "geos" dtype column')
+
         self._obj = obj
 
     def from_geopandas(self):
+        """ DEPRECATED: Use :meth:`~pgpd.GeosDataFrameAccessor.to_geos` instead. """
+        warnings.warn('from_geopandas() is deprecated; use to_geos().', warnings.DeprecationWarning)
+        return self.to_geos()
+
+    def to_geos(self):
         """
         Transform a :class:`geopandas.GeoDataFrame` into a regular DataFrame with a geos column.
 
